@@ -1,7 +1,10 @@
 mod channels;
+mod colorize;
 mod conv;
+// mod drawing;
 mod effects;
 mod filters;
+//mod font;
 mod gif;
 mod image;
 mod monochrome;
@@ -9,7 +12,6 @@ mod multiple;
 mod noise;
 mod rgb;
 mod transformations;
-
 use pyo3::prelude::*;
 
 #[pymodule]
@@ -17,5 +19,7 @@ fn polaroid(_py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_class::<image::Image>()?;
     m.add_class::<gif::Gif>()?;
     m.add_class::<rgb::Rgb>()?;
+    m.add_class::<rgb::Rgba>()?;
+    // m.add_class::<drawing::ImageDraw>()?;
     Ok(())
 }
